pub struct Color {
pub id: u32,
pub name: String,
}Fields
id: u32name: StringTrait Implementations
Sourceimpl CompatFrom<Color> for Color
impl CompatFrom<Color> for Color
Sourcefn compat_from(value: Color) -> Self
fn compat_from(value: Color) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<Color> for Color
impl CompatFrom<Color> for Color
Sourcefn compat_from(value: Color) -> Self
fn compat_from(value: Color) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<Color<'static>, ___E> for &'a Colorwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<Color<'static>, ___E> for &'a Colorwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourceimpl<___E> Encode<Color<'static>, ___E> for Colorwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<Color<'static>, ___E> for Colorwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Color<'static>>, ___E> for &'a Color
impl<'a, ___E> EncodeOption<Box<'static, Color<'static>>, ___E> for &'a Color
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Color<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Color<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Color<'static>>, ___E> for Color
impl<___E> EncodeOption<Box<'static, Color<'static>>, ___E> for Color
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Color<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Color<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWireRef<Color<'de>> for Color
impl<'de> FromWireRef<Color<'de>> for Color
Sourcefn from_wire_ref(wire: &Color<'de>) -> Self
fn from_wire_ref(wire: &Color<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for Color
impl Ord for Color
Sourceimpl PartialOrd for Color
impl PartialOrd for Color
impl Eq for Color
impl StructuralPartialEq for Color