pub struct EchoEchoStringRequest {
pub value: String,
}Fields
value: StringTrait Implementations
Sourceimpl Clone for EchoEchoStringRequest
impl Clone for EchoEchoStringRequest
Sourcefn clone(&self) -> EchoEchoStringRequest
fn clone(&self) -> EchoEchoStringRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<EchoEchoStringRequest> for EchoEchoStringRequest
impl CompatFrom<EchoEchoStringRequest> for EchoEchoStringRequest
Sourcefn compat_from(value: EchoEchoStringRequest) -> Self
fn compat_from(value: EchoEchoStringRequest) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<EchoEchoStringRequest> for EchoEchoStringRequest
impl CompatFrom<EchoEchoStringRequest> for EchoEchoStringRequest
Sourcefn compat_from(value: EchoEchoStringRequest) -> Self
fn compat_from(value: EchoEchoStringRequest) -> Self
Converts
value into a value of this type.Sourceimpl Debug for EchoEchoStringRequest
impl Debug for EchoEchoStringRequest
Sourceimpl<'a, ___E> Encode<EchoEchoStringRequest<'static>, ___E> for &'a EchoEchoStringRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<EchoEchoStringRequest<'static>, ___E> for &'a EchoEchoStringRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EchoEchoStringRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EchoEchoStringRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EchoEchoStringRequest<'static>, ___E> for EchoEchoStringRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<EchoEchoStringRequest<'static>, ___E> for EchoEchoStringRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EchoEchoStringRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EchoEchoStringRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, EchoEchoStringRequest<'static>>, ___E> for &'a EchoEchoStringRequestwhere
___E: Encoder + ?Sized,
&'a EchoEchoStringRequest: Encode<EchoEchoStringRequest<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, EchoEchoStringRequest<'static>>, ___E> for &'a EchoEchoStringRequestwhere
___E: Encoder + ?Sized,
&'a EchoEchoStringRequest: Encode<EchoEchoStringRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EchoEchoStringRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EchoEchoStringRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, EchoEchoStringRequest<'static>>, ___E> for EchoEchoStringRequest
impl<___E> EncodeOption<Box<'static, EchoEchoStringRequest<'static>>, ___E> for EchoEchoStringRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EchoEchoStringRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EchoEchoStringRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<EchoEchoStringRequest<'de>> for EchoEchoStringRequest
impl<'de> FromWire<EchoEchoStringRequest<'de>> for EchoEchoStringRequest
Sourcefn from_wire(wire: EchoEchoStringRequest<'de>) -> Self
fn from_wire(wire: EchoEchoStringRequest<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<EchoEchoStringRequest<'de>> for EchoEchoStringRequest
impl<'de> FromWireRef<EchoEchoStringRequest<'de>> for EchoEchoStringRequest
Sourcefn from_wire_ref(wire: &EchoEchoStringRequest<'de>) -> Self
fn from_wire_ref(wire: &EchoEchoStringRequest<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for EchoEchoStringRequest
impl Hash for EchoEchoStringRequest
Sourceimpl Ord for EchoEchoStringRequest
impl Ord for EchoEchoStringRequest
Sourcefn cmp(&self, other: &EchoEchoStringRequest) -> Ordering
fn cmp(&self, other: &EchoEchoStringRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EchoEchoStringRequest
impl PartialEq for EchoEchoStringRequest
Sourceimpl PartialOrd for EchoEchoStringRequest
impl PartialOrd for EchoEchoStringRequest
impl Eq for EchoEchoStringRequest
impl StructuralPartialEq for EchoEchoStringRequest