#[repr(C)]pub struct GameState {}Trait Implementations
Sourceimpl CompatFrom<GameState> for GameState
impl CompatFrom<GameState> for GameState
Sourcefn compat_from(value: GameState) -> Self
fn compat_from(value: GameState) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<GameState> for GameState
impl CompatFrom<GameState> for GameState
Sourcefn compat_from(value: GameState) -> Self
fn compat_from(value: GameState) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<GameState, ___E> for &'a GameStatewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GameState, ___E> for &'a GameStatewhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<GameState, ___E> for GameStatewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GameState, ___E> for GameStatewhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<'a, ___E> EncodeOption<Box<'static, GameState>, ___E> for &'a GameState
impl<'a, ___E> EncodeOption<Box<'static, GameState>, ___E> for &'a GameState
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GameState>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GameState>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, GameState>, ___E> for GameState
impl<___E> EncodeOption<Box<'static, GameState>, ___E> for GameState
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GameState>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GameState>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<GameState> for GameState
impl FromWireRef<GameState> for GameState
Sourcefn from_wire_ref(wire: &GameState) -> Self
fn from_wire_ref(wire: &GameState) -> Self
Converts the given reference to this type.
Sourceimpl Ord for GameState
impl Ord for GameState
Sourceimpl PartialOrd for GameState
impl PartialOrd for GameState
impl Copy for GameState
impl Eq for GameState
impl StructuralPartialEq for GameState